@@ -1,9 +1,10 @@
 #!/bin/bash
 
-source $TOP/tests/common
+source "$TEST_TOP/common" || exit
+
+check_prereq btrfs
 
 setup_root_helper
-check_prereq btrfs
 
 # redefine the one provided by common
 check_image() {
@@ -11,10 +12,10 @@ check_image() {
 
 	image=$1
 	run_check cp "$image" "$image".scratch
-	run_mayfail $TOP/btrfs rescue zero-log "$image".scratch
+	run_mayfail "$TOP/btrfs" rescue zero-log "$image".scratch
 	rm -- "$image".scratch
 }
 
-check_all_images $TOP/tests/fuzz-tests/images
+check_all_images "$TEST_TOP/fuzz-tests/images"
 
 exit 0
